##########
User Guide
##########

Welcome to the Ansible User Guide!

This guide covers how to work with Ansible, including using the command line, working with inventory, and writing playbooks.

.. toctree::
   :maxdepth: 2

   quickstart
   basic_concepts
   intro_getting_started
   intro_inventory
   intro_dynamic_inventory
   intro_patterns
   intro_adhoc
   connection_details
   command_line_tools
   playbooks
   become
   vault
   modules
   ../plugins/plugins
   intro_bsd
   windows
   collections_using
